@@ -30,7 +30,7 @@ has _pa => (
     },
 ); # store Perinci::Access object
 
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -56,7 +56,7 @@ sub before_gen_doc {
     # let's retrieve the metadatas first, skip if already provided in _meta
     return if $self->{_meta};
 
-    $log->tracef("=> FuncBase's before_generate_doc(opts=%s)", \%opts);
+    $log->tracef("=> FuncBase's before_gen_doc(opts=%s)", \%opts);
 
     my $res = $self->_pa->request(info=>$self->{url});
     $res->[0] == 200 or die "Can't info $self->{url}: $res->[0] - $res->[1]";
@@ -206,7 +206,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =for Pod::Coverage .+
 
